import org.aspectj.lang.annotation.Pointcut;
import org.springframework.context.ApplicationContext;
import org.springframework.context.support.ClassPathXmlApplicationContext;
import org.springframework.transaction.TransactionDefinition;
import org.springframework.transaction.TransactionException;
import org.springframework.transaction.support.AbstractPlatformTransactionManager;
import org.springframework.transaction.support.DefaultTransactionStatus;

import bean.SimpleBean;
import bean.TestBean2;

public class Main {
  public static void main(String[] args) {
    ApplicationContext ac = new ClassPathXmlApplicationContext("context.xml");
    TestBean2 testBean = (TestBean2) ac.getBean("test");
    SimpleBean simpleBean = (SimpleBean) ac.getBean("simple");
    testBean.work();
    testBean.stop();
    simpleBean.sayHello();
    simpleBean.x("a", "b");
  }
}
final class SystemPointcuts {
  private SystemPointcuts() {
  }

  @Pointcut("execution(* bean..*.*(..)) &&" +
          "!execution(* bean..*.set*(..)) &&" +
          "!execution(* bean..*.get*())")
  public void serviceExecution() { }

  @Pointcut("within(bean.TestBean2)")
  public void within1() { }

  @Pointcut("execution(* bean.TestBean2.*(..))")
  public void testBeanExecution() { }

  @Pointcut("execution(* bean.TestBean2.*(..))")
  private void testBeanExec() { }

  @Pointcut("execution(* bean..*.*(..))")
  public void inProsringPackage() { }

  @Pointcut("within(bean..*)")
  private void withinProSpringPackage() { }

  @Pointcut("execution(* bean.TestBean2.*(..)) &&" +
          "within(bean..*)")
  public void same1() { }

  @Pointcut("execution(* bean.TestBean2.*(..)) &&" +
          "withinProSpringPackage()")
  public void same2() { }

  @Pointcut("testBeanExec() && withinProSpringPackage()")
  public void same3() { }


  @Pointcut("within(bean.TestBean2)")
  public void fromTestBeanExecution() { }

  @Pointcut("this(bean.SimpleBean)")
  public void onlyFromSimpleBean() { }

  @Pointcut("target(bean.SimpleBean)")
  public void onlyToSimpleBean() { }

  @Pointcut("args(String, String)")
  public void onlyTwoStringArguments() { }

//  @Pointcut("bean(test)")
  public void beanName() { }
}
class NoopTransactionManager extends AbstractPlatformTransactionManager {

  protected Object doGetTransaction() throws TransactionException {
      return new Object();
  }

  protected void doBegin(Object object, TransactionDefinition transactionDefinition) throws TransactionException {
      System.out.println("Begin");
  }

  protected void doCommit(DefaultTransactionStatus defaultTransactionStatus) throws TransactionException {
      System.out.println("Commit");
  }

  protected void doRollback(DefaultTransactionStatus defaultTransactionStatus) throws TransactionException {
      System.out.println("Rollback");
  }
}
